Window
===========================

.. currentmodule:: enaml.widgets.window

.. autoclass:: Window


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_window.QtWindow
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_window.QtWindow

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_window.WXWindow
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_window.WXWindow
